@@ -6,8 +6,8 @@
 #include "pythonic/types/traits.hpp"
 #include "pythonic/utils/functor.hpp"
 
-#include <tuple>
 #include <iterator>
+#include <tuple>
 
 PYTHONIC_NS_BEGIN
 
@@ -20,10 +20,10 @@ namespace builtins
   }
 
   template <class T>
-  typename std::enable_if<types::has_size<T>::value, long>::type len(T const &t)
+  std::enable_if_t<types::has_size<T>::value, long> len(T const &t)
   {
     return t.size();
   }
-}
+} // namespace builtins
 PYTHONIC_NS_END
 #endif
