@@ -4,8 +4,8 @@
 #include "pythonic/include/builtins/list/sort.hpp"
 
 #include "pythonic/builtins/None.hpp"
-#include "pythonic/types/list.hpp"
 #include "pythonic/types/NoneType.hpp"
+#include "pythonic/types/list.hpp"
 #include "pythonic/utils/functor.hpp"
 #include "pythonic/utils/pdqsort.hpp"
 
@@ -27,12 +27,11 @@ namespace builtins
     template <class T, class K>
     types::none_type sort(types::list<T> &seq, K key)
     {
-      pdqsort(seq.begin(), seq.end(), [&key](T const &self, T const &other) {
-        return key(self) < key(other);
-      });
+      pdqsort(seq.begin(), seq.end(),
+              [&key](T const &self, T const &other) { return key(self) < key(other); });
       return builtins::None;
     }
-  }
-}
+  } // namespace list
+} // namespace builtins
 PYTHONIC_NS_END
 #endif
