@@ -18,10 +18,10 @@ namespace builtins
 
     bool isdigit(types::str const &s)
     {
-      return !s.empty() && std::all_of(s.chars().begin(), s.chars().end(),
-                                       (int (*)(int))std::isdigit);
+      return !s.empty() &&
+             std::all_of(s.chars().begin(), s.chars().end(), (int (*)(int))std::isdigit);
     }
-  }
-}
+  } // namespace str
+} // namespace builtins
 PYTHONIC_NS_END
 #endif
