@@ -1,8 +1,8 @@
 #ifndef PYTHONIC_INCLUDE_NUMPY_COPYTO_HPP
 #define PYTHONIC_INCLUDE_NUMPY_COPYTO_HPP
 
-#include "pythonic/include/utils/functor.hpp"
 #include "pythonic/include/types/ndarray.hpp"
+#include "pythonic/include/utils/functor.hpp"
 
 PYTHONIC_NS_BEGIN
 namespace numpy
@@ -21,13 +21,14 @@ namespace numpy
 
   // pythran extensions
   template <class E, class F>
-  types::none_type copyto(E &out, F const &expr) {
+  types::none_type copyto(E &out, F const &expr)
+  {
     out[types::fast_contiguous_slice(0, types::none_type{})] = expr;
     return {};
   }
 
   DEFINE_FUNCTOR(pythonic::numpy, copyto);
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
