@@ -1,9 +1,9 @@
 #ifndef PYTHONIC_INCLUDE_NUMPY_NANARGMAX_HPP
 #define PYTHONIC_INCLUDE_NUMPY_NANARGMAX_HPP
 
-#include "pythonic/include/utils/functor.hpp"
-#include "pythonic/include/types/ndarray.hpp"
 #include "pythonic/include/numpy/isnan.hpp"
+#include "pythonic/include/types/ndarray.hpp"
+#include "pythonic/include/utils/functor.hpp"
 
 PYTHONIC_NS_BEGIN
 
@@ -13,7 +13,7 @@ namespace numpy
   long nanargmax(E const &expr);
 
   DEFINE_FUNCTOR(pythonic::numpy, nanargmax);
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
