@@ -11,14 +11,14 @@ namespace numpy
 {
 
   template <class... Args>
-  auto sum(Args &&... args)
+  auto sum(Args &&...args)
       -> decltype(reduce<operator_::functor::iadd>(std::forward<Args>(args)...))
   {
     return reduce<operator_::functor::iadd>(std::forward<Args>(args)...);
   }
 
   DEFINE_FUNCTOR(pythonic::numpy, sum);
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
