@@ -26,25 +26,22 @@ namespace functor
     NUMPY_NARY_EXTRA_METHOD
 
     template <typename... T>
-    auto operator()(T &&... args) const -> typename std::enable_if<
-        !types::valid_numexpr_parameters<
-            typename std::decay<T>::type...>::value,
-        decltype(NUMPY_NARY_FUNC_SYM(std::forward<T>(args)...))>::type;
+    auto operator()(T &&...args) const
+        -> std::enable_if_t<!types::valid_numexpr_parameters<std::decay_t<T>...>::value,
+                            decltype(NUMPY_NARY_FUNC_SYM(std::forward<T>(args)...))>;
 
     template <class... E>
-    typename std::enable_if<
-        types::valid_numexpr_parameters<typename std::decay<E>::type...>::value,
-        types::numpy_expr<
-            NUMPY_NARY_FUNC_NAME,
-            typename types::NUMPY_NARY_RESHAPE_MODE<E, E...>::type...>>::type
-    operator()(E &&... args) const;
+    std::enable_if_t<types::valid_numexpr_parameters<std::decay_t<E>...>::value,
+                     types::numpy_expr<NUMPY_NARY_FUNC_NAME,
+                                       typename types::NUMPY_NARY_RESHAPE_MODE<E, E...>::type...>>
+    operator()(E &&...args) const;
 
     friend std::ostream &operator<<(std::ostream &os, NUMPY_NARY_FUNC_NAME)
     {
       return os << STR(NUMPY_NARY_FUNC_NAME);
     }
   };
-}
+} // namespace functor
 
 #undef NUMPY_NARY_FUNC_NAME
 #undef NUMPY_NARY_FUNC_SYM
