@@ -3,8 +3,8 @@
 
 #include "pythonic/include/numpy/arcsinh.hpp"
 
-#include "pythonic/utils/functor.hpp"
 #include "pythonic/types/ndarray.hpp"
+#include "pythonic/utils/functor.hpp"
 #include "pythonic/utils/numpy_traits.hpp"
 
 PYTHONIC_NS_BEGIN
@@ -14,7 +14,7 @@ namespace numpy
 #define NUMPY_NARY_FUNC_NAME arcsinh
 #define NUMPY_NARY_FUNC_SYM xsimd::asinh
 #include "pythonic/types/numpy_nary_expr.hpp"
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
