@@ -3,9 +3,9 @@
 
 #include "pythonic/include/numpy/cumsum.hpp"
 
-#include "pythonic/utils/functor.hpp"
 #include "pythonic/numpy/partial_sum.hpp"
 #include "pythonic/operator_/iadd.hpp"
+#include "pythonic/utils/functor.hpp"
 
 PYTHONIC_NS_BEGIN
 
@@ -13,14 +13,13 @@ namespace numpy
 {
 
   template <class E, class... Opts>
-  auto cumsum(E &&e, Opts &&... opts)
-      -> decltype(partial_sum<operator_::functor::add>(
-          std::forward<E>(e), std::forward<Opts>(opts)...))
+  auto cumsum(E &&e, Opts &&...opts)
+      -> decltype(partial_sum<operator_::functor::add>(std::forward<E>(e),
+                                                       std::forward<Opts>(opts)...))
   {
-    return partial_sum<operator_::functor::add>(std::forward<E>(e),
-                                                std::forward<Opts>(opts)...);
+    return partial_sum<operator_::functor::add>(std::forward<E>(e), std::forward<Opts>(opts)...);
   }
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
