@@ -3,8 +3,8 @@
 
 #include "pythonic/include/numpy/finfo.hpp"
 
-#include "pythonic/utils/functor.hpp"
 #include "pythonic/types/finfo.hpp"
+#include "pythonic/utils/functor.hpp"
 
 PYTHONIC_NS_BEGIN
 
@@ -15,7 +15,7 @@ namespace numpy
   {
     return types::finfo<typename dtype::type>();
   }
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
