@@ -3,8 +3,8 @@
 
 #include "pythonic/include/numpy/isinf.hpp"
 
-#include "pythonic/utils/functor.hpp"
 #include "pythonic/types/ndarray.hpp"
+#include "pythonic/utils/functor.hpp"
 #include "pythonic/utils/numpy_traits.hpp"
 
 PYTHONIC_NS_BEGIN
@@ -23,11 +23,11 @@ namespace numpy
     {
       return std::isinf(v.real()) || std::isinf(v.imag());
     }
-  }
+  } // namespace wrapper
 #define NUMPY_NARY_FUNC_NAME isinf
 #define NUMPY_NARY_FUNC_SYM wrapper::isinf
 #include "pythonic/types/numpy_nary_expr.hpp"
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
