@@ -3,9 +3,9 @@
 
 #include "pythonic/include/numpy/ndarray/tolist.hpp"
 
+#include "pythonic/types/ndarray.hpp"
 #include "pythonic/utils/functor.hpp"
 #include "pythonic/utils/numpy_conversion.hpp"
-#include "pythonic/types/ndarray.hpp"
 
 PYTHONIC_NS_BEGIN
 
@@ -16,17 +16,15 @@ namespace numpy
   {
 
     template <class T, class pS>
-    typename std::enable_if<std::tuple_size<pS>::value == 1,
-                            types::list<T>>::type
+    std::enable_if_t<std::tuple_size<pS>::value == 1, types::list<T>>
     tolist(types::ndarray<T, pS> const &expr)
     {
       return {expr.fbegin(), expr.fend()};
     }
 
     template <class T, class pS>
-    typename std::enable_if<
-        std::tuple_size<pS>::value != 1,
-        typename tolist_type<T, std::tuple_size<pS>::value>::type>::type
+    std::enable_if_t<std::tuple_size<pS>::value != 1,
+                     typename tolist_type<T, std::tuple_size<pS>::value>::type>
     tolist(types::ndarray<T, pS> const &expr)
     {
       typename tolist_type<T, std::tuple_size<pS>::value>::type out(0);
@@ -36,8 +34,8 @@ namespace numpy
     }
 
     NUMPY_EXPR_TO_NDARRAY0_IMPL(tolist);
-  }
-}
+  } // namespace ndarray
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
