@@ -22,16 +22,15 @@ namespace scipy
       double kvp(T0 x, T1 y)
       {
         using namespace boost::math::policies;
-        return boost::math::cyl_bessel_k_prime(
-            x, y, make_policy(promote_double<true>()));
+        return boost::math::cyl_bessel_k_prime(x, y, make_policy(promote_double<true>()));
       }
-    }
+    } // namespace details
 
 #define NUMPY_NARY_FUNC_NAME kvp
 #define NUMPY_NARY_FUNC_SYM details::kvp
 #include "pythonic/types/numpy_nary_expr.hpp"
-  }
-}
+  } // namespace special
+} // namespace scipy
 PYTHONIC_NS_END
 
 #endif
