@@ -3,9 +3,9 @@
 
 #include "pythonic/include/utils/nested_container.hpp"
 
-#include <limits>
 #include "pythonic/types/traits.hpp"
 #include "pythonic/utils/numpy_traits.hpp"
+#include <limits>
 
 PYTHONIC_NS_BEGIN
 namespace utils
@@ -15,11 +15,12 @@ namespace utils
   long nested_container_size<T>::flat_size(T const &t)
   {
     auto n = t.size();
-    return n ? n * nested_container_size<typename std::conditional<
-               // If we have a scalar or a complex, we want to stop
-               // recursion, and then dispatch to bool specialization
-               types::is_dtype<typename Type::value_type>::value, bool,
-               typename Type::value_type>::type>::flat_size(*t.begin()) : 0;
+    return n ? n * nested_container_size<std::conditional_t<
+                       // If we have a scalar or a complex, we want to stop
+                       // recursion, and then dispatch to bool specialization
+                       types::is_dtype<typename Type::value_type>::value, bool,
+                       typename Type::value_type>>::flat_size(*t.begin())
+             : 0;
   }
 
   /* Recursion stops on bool */
@@ -28,7 +29,7 @@ namespace utils
   {
     return 1;
   }
-}
+} // namespace utils
 PYTHONIC_NS_END
 
 #endif
